@@ -1,16 +1,15 @@
 from .convert.xlsx import convert_to_xlsx, write_workbook
 from .convert.csv import convert_to_csv
 from .convert.json import convert_to_json
-from .compare import ModelComparer
+from hycli.commons.excel_adapter import ExcelAdapter
 from .evaluation.evaluation import Evaluation
 
-
-__version__ = "0.5.1"
+__version__ = "0.6.0"
 __all__ = [
     "convert_to_csv",
     "convert_to_xlsx",
     "convert_to_json",
     "write_workbook",
-    "ModelComparer",
+    "ExcelAdapter",
     "Evaluation"
 ]
